@@ -1,5 +1,6 @@
 import os
 import subprocess as sp
+import sys
 
 SCRIPT_DIR = os.path.dirname(os.path.abspath(__file__))
 
@@ -10,12 +11,19 @@ def run(cmd):
 
 
 def run_tests():
-    run(["pytest", os.path.join(SCRIPT_DIR, "test")])
     run(
         [
-            "python",
+            sys.executable,
             "-c",
-            "import crc32c; import time; x = b' ' * int(1e9); n = 10; s = time.time(); [crc32c.crc32(x) for _ in range(n)]; print('Ran at %.3f [GB/s]' % (n/(time.time() - s),))",
+            "import crc32c; print('Is big endian? ', crc32c.big_endian)",
+        ]
+    )
+    run([sys.executable, "-mpytest", os.path.join(SCRIPT_DIR, "test")])
+    run(
+        [
+            sys.executable,
+            "-c",
+            "import crc32c; import time; x = b' ' * int(1e9); n = 10; s = time.time(); [crc32c.crc32c(x) for _ in range(n)]; print('Ran at %.3f [GB/s]' % (n/(time.time() - s),))",
         ]
     )
 
